silicate-package: silicate

silicate-packageR Documentation

silicate

Description

Decomposes spatial data (of various formats) into simpler forms, including paths, triangles or segments. A development tool for exploring the underlying structures of spatial data, and for converting it to something else. The models PATH(), TRI(), SC() and ARC() provide relational tables of all underlying entities, and more specialist versions PATH0(), TRI0() and SC0() provide more efficient topological representations of polygons or lines.

Author(s)

Maintainer: Michael D. Sumner mdsumner@gmail.com

Authors:

Other contributors:

  • John Corbett (the original inspiration) [contributor]

  • Simon Wotherspoon [contributor]

  • Kent Johnson [data contributor]

See Also

Useful links:


silicate documentation built on Oct. 11, 2026, 9:07 a.m.